# encoding: utf-8
require "logstash/devutils/rspec/spec_helper"
require "logstash/codecs/transit"
require "logstash/event"
require "insist"

describe LogStash::Codecs::Transit do
  def codec_test
    data = {"foo" => "bar", "baz" => {"bah" => ["a","b","c"]}, "date" => DateTime.new(2015,2,3)}
    event = LogStash::Event.new(data)
    encoded = nil
    subject.on_event do |e, d|
      encoded = d
      got_event = true
    end
    subject.encode(event)
    insist { got_event }

    subject.decode(encoded) do |event|
      insist { event.is_a? LogStash::Event }
      insist { event["foo"] } == data["foo"]
      insist { event["baz"] } == data["baz"]
      insist { event["bah"] } == data["bah"]
      insist { event["date"] } == data["date"]
    end
  end

  context "msgpack" do
    subject do
      LogStash::Codecs::Transit.new("transport" => "msgpack")
    end

    context "encode + decode" do
      it "should return an event from transit data" do
        codec_test
      end
    end
  end

  context "json" do
    subject do
      LogStash::Codecs::Transit.new("transport" => "json")
    end

    context "encode + decode" do
      it "should return an event from transit data" do
        codec_test
      end
    end
  end

  context "base64 msgpack" do
    subject do
      LogStash::Codecs::Transit.new("transport" => "msgpack", "base64" => true)
    end

    context "encode + decode" do
      it "should return an event from transit data" do
        codec_test
      end
    end
  end
end
